Patternfly testing page

## Widgetastic About Modal

- Field1 Field1Value
- Field2 Field2Value
- Field3 Field3Value

Widget Trademark and Copyright Information
Bootstrap datepicker readonly
Bootstrap datepicker readwrite
Patternfly Basic DatePicker

## 0 Ipsum

## 20 Amet

4 1

## Adipiscing

noclick

## 0 Ipsum

## 20 Amet

4

## 9 Adipiscing

N/A

# Line Charts

## Sparkline

Less than one year remaining

## Line Chart

## Single Line Chart

# Spline Chart

## Single Spline Chart

# Bar Charts

## Vertical Bar Chart

## Grouped Vertical Bar Chart

## Stacked Vertical Bar Chart

## Horizontal Bar Chart

## Grouped Horizontal Bar Chart

## Stacked Horizontal Bar Chart

#### Modal Title

Field One
Field Two
Field Three

- Environment / UAT

Retirement date set to 12/31/19 15:55 UTC
Retirement date removed
All changes have been reset
Set/remove retirement date was cancelled by the user
Retirement initiated for 1 VM and Instance from the CFME Database